SimpleDropdownFactory class

Simple dropdown factory for creating dropdowns with minimal configuration

Constructors

SimpleDropdownFactory()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

customDiamondMultiple<T>({required List<T> items, List<T>? value, required void onChanged(dynamic), required Widget itemBuilder(T), String? hintText, Color? activeColor}) Widget
Creates a multiple selection dropdown with custom diamond icon indicator
customDiamondSingle<T>({required List<T> items, T? value, required void onChanged(dynamic), required Widget itemBuilder(T), String? hintText, Color? activeColor}) Widget
Creates a single selection dropdown with custom diamond icon indicator
customHeartMultiple<T>({required List<T> items, List<T>? value, required void onChanged(dynamic), required Widget itemBuilder(T), String? hintText, Color? activeColor}) Widget
Creates a multiple selection dropdown with custom heart icon indicator
customHeartSingle<T>({required List<T> items, T? value, required void onChanged(dynamic), required Widget itemBuilder(T), String? hintText, Color? activeColor}) Widget
Creates a single selection dropdown with custom heart icon indicator
customStarMultiple<T>({required List<T> items, List<T>? value, required void onChanged(dynamic), required Widget itemBuilder(T), String? hintText, Color? activeColor}) Widget
Creates a multiple selection dropdown with custom star icon indicator
customStarSingle<T>({required List<T> items, T? value, required void onChanged(dynamic), required Widget itemBuilder(T), String? hintText, Color? activeColor}) Widget
Creates a single selection dropdown with custom star icon indicator
dotCheckbox<T>({required List<T> items, List<T>? value, required void onChanged(dynamic), required Widget itemBuilder(T), String? hintText, Color? activeColor}) Widget
Creates a multiple selection dropdown with dot checkbox style
gradientCheckbox<T>({required List<T> items, List<T>? value, required void onChanged(dynamic), required Widget itemBuilder(T), required List<Color> gradientColors, String? hintText}) Widget
Creates a multiple selection dropdown with gradient checkbox
gradientRadio<T>({required List<T> items, T? value, required void onChanged(dynamic), required Widget itemBuilder(T), required List<Color> gradientColors, String? hintText}) Widget
Creates a single selection dropdown with gradient radio
multiple<T>({required List<T> items, List<T>? value, required void onChanged(dynamic), required Widget itemBuilder(T), String? hintText, Widget? hint, DropdownAnimationType animationType = DropdownAnimationType.liquid, Color? highlightColor, BorderRadius? borderRadius, double? height, double? width, bool showChips = true, bool enableSearch = false, IndicatorType indicatorType = IndicatorType.checkmark, double? indicatorSize, Widget customIndicatorBuilder(BuildContext, bool isSelected, Color activeColor)?}) Widget
Creates a simple multiple selection dropdown
radio<T>({required List<T> items, T? value, required void onChanged(dynamic), required Widget itemBuilder(T), String? hintText, Color? activeColor, double? size}) Widget
Creates a single selection dropdown with radio button style
single<T>({required List<T> items, T? value, required void onChanged(dynamic), required Widget itemBuilder(T), String? hintText, Widget? hint, DropdownAnimationType animationType = DropdownAnimationType.glass, Color? highlightColor, BorderRadius? borderRadius, double? height, double? width, bool showCheckmark = true, IndicatorType indicatorType = IndicatorType.radioClassic, double? indicatorSize, Widget customIndicatorBuilder(BuildContext, bool isSelected, Color activeColor)?}) Widget
Creates a simple single selection dropdown
styledMultiple<T>({required List<T> items, List<T>? value, required void onChanged(dynamic), required Widget itemBuilder(T), required SimpleDropdownStyle style}) Widget
Creates a multiple selection dropdown with custom styling
styledSingle<T>({required List<T> items, T? value, required void onChanged(dynamic), required Widget itemBuilder(T), required SimpleDropdownStyle style}) Widget
Creates a single selection dropdown with custom styling
switchStyle<T>({required List<T> items, T? value, required void onChanged(dynamic), required Widget itemBuilder(T), String? hintText, Color? activeColor}) Widget
Creates a single selection dropdown with switch style
toggle<T>({required List<T> items, T? value, required void onChanged(dynamic), required Widget itemBuilder(T), String? hintText, Color? activeColor}) Widget
Creates a single selection dropdown with toggle style