MultiDropdownAnimationStrategy<T> class
abstract
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildDropdown({required BuildContext context, required List<T> items, required dynamic value, required ValueChanged<T> onChanged, required Widget itemBuilder(T item), Widget? hint, Widget? icon, required AnimationController controller, required bool isOpen, required MultiDropDownConfig config, required VoidCallback onToggle, bool showDivider = true, Color? dividerColor, double? dividerThickness, EdgeInsets? padding, EdgeInsets? itemPadding, TextStyle? hintStyle, TextStyle? selectedItemStyle, TextStyle? itemStyle, Color? dropdownBackgroundColor, BoxShadow? shadow, List<BoxShadow>? shadows, double? elevation, double? maxDropdownHeight, bool showCheckmark = true, Widget? customCheckmark, double? dropdownWidth, required bool isItemSelected(T), required Widget buildSelectionIndicator(bool, MultiDropDownConfig), required Widget buildSearchField(MultiDropDownConfig), Widget noDataBuilder()?})
→ Widget
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toggleDropdown({required AnimationController controller, required bool isOpen})
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited